@@ -5,23 +5,23 @@
 # Source file position: <groff-source>/contrib/groffer/roff2.pl
 # Installed position: <prefix>/bin/roff2*
 
-# Copyright (C) 2006-2014  Free Software Foundation, Inc.
+# Copyright (C) 2006-2018 Free Software Foundation, Inc.
 # Written by Bernd Warken <groff-bernd.warken-72@web.de>.
 
-# This file is part of `groffer', which is part of `groff'.
+# This file is part of 'groffer', which is part of 'groff'.
 
-# `groff' is free software; you can redistribute it and/or modify it
+# 'groff' is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
-# `groff' is distributed in the hope that it will be useful, but
+# 'groff' is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program. If not, see
+# along with this program.  If not, see
 # <http://www.gnu.org/licenses/gpl-2.0.html>.
 
 ########################################################################
@@ -197,12 +197,12 @@ usage: $Name [option]... [--] [filespec]...
 -h | --help     print usage information
 -v | --version  print version information
 
-All other options are arbitrary options of `groffer'; the options
+All other options are arbitrary options of 'groffer'; the options
 override the behavior of this program.
 
-filespec's are the same as in `groffer': either the names of existing,
-readable files or `-' for standard input or a search pattern for man
-pages.  No `filespec' assumes standard input automatically.
+filespec's are the same as in 'groffer': either the names of existing,
+readable files or '-' for standard input or a search pattern for man
+pages.  No 'filespec' assumes standard input automatically.
 EOF
 }
 
@@ -213,10 +213,10 @@ usage: $Name [option]... [--] [filespec]...
 -h | --help     print usage information
 -v | --version  print version information
 
-No other options are allowed because `groffer' is not available.
+No other options are allowed because 'groffer' is not available.
 
-The only `filespec's allowed are the names of existing, readable files
-or `-' for standard input.  No `filespec' assumes standard input
+The only 'filespec's allowed are the names of existing, readable files
+or '-' for standard input.  No 'filespec' assumes standard input
 automatically.
 EOF
 }
