@@ -1,7 +1,6 @@
 #! /usr/bin/perl
 # -*- Perl -*-
-# Copyright (C) 1989, 2005, 2009
-# Free Software Foundation, Inc.
+# Copyright (C) 1989-2018 Free Software Foundation, Inc.
 #
 # This file is part of groff.
 #
@@ -16,7 +15,7 @@
 # for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 use strict;
 # runs groff in safe mode, that seems to be the default
@@ -153,3 +152,11 @@ sub psbb {
 	}
 	close(IN);
 }
+
+
+1;
+########################################################################
+### Emacs settings
+# Local Variables:
+# mode: CPerl
+# End:
