@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+/* Copyright (C) 2002-2018  Free Software Foundation, Inc.
  *
  *  Gaius Mulley (gaius@glam.ac.uk) wrote html-table.h
  *
@@ -14,17 +14,16 @@ This file is part of groff.
 
 groff is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 groff is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
-You should have received a copy of the GNU General Public License along
-with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 51 Franklin St - Fifth Floor, Boston, MA 02110-1301, USA. */
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "html.h"
 
@@ -93,6 +92,8 @@ public:
   void  finish_row        (void);
   int   get_effective_linelength (void);
   void  set_space         (int space);
+  void  emit_colspan      (void);
+  void  emit_td           (int percentage, const char *s = ">");
 
   tabs          *tab_stops;    /* tab stop positions */
   simple_output *out;
@@ -100,7 +101,7 @@ private:
   cols          *columns;      /* column entries */
   int            linelength;
   cols          *last_col;     /* last column started */
-  int            start_space;  /* have we seen a `.sp' tag? */
+  int            start_space;  /* have we seen a '.sp' tag? */
 
   void  remove_cols (cols *c);
 };
@@ -121,7 +122,7 @@ public:
   // the indent is shutdown when it is deleted
 
 private:
-  void end     (void);
+  void end    (void);
   int         is_used;
   int         pg;        // values of the registers as passed via initialization
   int         ll;
