@@ -1,23 +1,21 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2002, 2003
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
 
 groff is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 groff is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
-You should have received a copy of the GNU General Public License along
-with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 class ps_output {
 public:
@@ -54,14 +52,16 @@ inline FILE *ps_output::get_file()
   return fp;
 }
 
+// this must stay in sync with 'resource_table' in 'psrm.cpp'
 enum resource_type {
   RESOURCE_FONT,
+  RESOURCE_FONTSET,
   RESOURCE_PROCSET,
   RESOURCE_FILE,
   RESOURCE_ENCODING,
   RESOURCE_FORM,
   RESOURCE_PATTERN
-  };
+};
 
 struct resource;
 
@@ -123,3 +123,7 @@ enum {
   USE_PS_ADOBE_2_0 = 010,
   NO_PAPERSIZE = 020
 };
+
+#include "searchpath.h"
+
+extern search_path include_search_path;
