@@ -1,27 +1,30 @@
 // -*- C++ -*-
-/* Copyright (C) 1989-2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
 
 groff is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 groff is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
-You should have received a copy of the GNU General Public License along
-with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#if defined(__INTERIX) && !defined(_ALL_SOURCE)
+#define _ALL_SOURCE
+#endif
+
 extern "C" {
 #ifndef HAVE_STRERROR
   char *strerror(int);
@@ -31,28 +34,22 @@ extern "C" {
   const char *if_to_a(int, int);
 }
 
-/* stdio.h on IRIX, OSF/1, emx, UWIN, and MinGW include getopt.h */
-/* unistd.h on CYGWIN includes getopt.h */
-
-#if !(defined(__sgi) \
-      || (defined(__osf__) && defined(__alpha)) \
-      || defined(_UWIN) \
-      || defined(__EMX__) \
-      || defined(__CYGWIN__) \
-      || defined(__MINGW32__))
-#include <groff-getopt.h>
-#else
+#define __GETOPT_PREFIX groff_
 #include <getopt.h>
-#endif
 
 #ifdef HAVE_SETLOCALE
 #include <locale.h>
-#else
-#define setlocale(category, locale) do {} while(0)
-#endif
+#define getlocale(category) setlocale(category, NULL)
+#else /* !HAVE_SETLOCALE */
+#define LC_ALL 0
+#define LC_CTYPE 0
+#define setlocale(category, locale) (void)(category, locale)
+#define getlocale(category) ((void)(category), (char *)"C")
+#endif /* !HAVE_SETLOCALE */
 
 char *strsave(const char *s);
 int is_prime(unsigned);
+double groff_hypot(double, double);
 
 #include <stdio.h>
 #include <string.h>
@@ -62,16 +59,6 @@ int is_prime(unsigned);
 
 #include <stdarg.h>
 
-/* HP-UX 10.20 and LynxOS 4.0.0 don't declare snprintf() */
-#if !defined(HAVE_SNPRINTF) || defined(NEED_DECLARATION_SNPRINTF)
-extern "C" { int snprintf(char *, size_t, const char *, /*args*/ ...); }
-#endif
-
-/* LynxOS 4.0.0 has snprintf() but no vsnprintf() */
-#if !defined(HAVE_VSNPRINTF) || defined(NEED_DECLARATION_VSNPRINTF)
-extern "C" { int vsnprintf(char *, size_t, const char *, va_list); }
-#endif
-
 /* LynxOS 4.0.0 doesn't declare vfprintf() */
 #ifdef NEED_DECLARATION_VFPRINTF
 extern "C" { int vfprintf(FILE *, const char *, va_list); }
@@ -99,8 +86,7 @@ extern "C" { int pclose (FILE *); }
 #endif /* NEED_DECLARATION_PCLOSE */
 
 size_t file_name_max(const char *fname);
-
-int interpret_lf_args(const char *p);
+size_t path_name_max();
 
 extern char invalid_char_table[];
 
@@ -114,7 +100,7 @@ inline int invalid_input_char(int c)
 // Ultrix4.3's string.h fails to declare this.
 extern "C" { int strcasecmp(const char *, const char *); }
 #endif /* NEED_DECLARATION_STRCASECMP */
-#else /* not HAVE_STRCASECMP */
+#else /* !HAVE_STRCASECMP */
 extern "C" { int strcasecmp(const char *, const char *); }
 #endif /* HAVE_STRCASECMP */
 
@@ -124,16 +110,16 @@ extern "C" { int strcasecmp(const char *, const char *); }
 // SunOS's string.h fails to declare this.
 extern "C" { int strncasecmp(const char *, const char *, int); }
 #endif /* NEED_DECLARATION_STRNCASECMP */
-#else /* not HAVE_STRNCASECMP */
+#else /* !HAVE_STRNCASECMP */
 extern "C" { int strncasecmp(const char *, const char *, size_t); }
 #endif /* HAVE_STRNCASECMP */
 #endif /* !_AIX && !sinix && !__sinix__ */
 
 #ifdef HAVE_CC_LIMITS_H
 #include <limits.h>
-#else /* not HAVE_CC_LIMITS_H */
+#else /* !HAVE_CC_LIMITS_H */
 #define INT_MAX 2147483647
-#endif /* not HAVE_CC_LIMITS_H */
+#endif /* !HAVE_CC_LIMITS_H */
 
 /* It's not safe to rely on people getting INT_MIN right (ie signed). */
 
@@ -147,14 +133,14 @@ extern "C" { int strncasecmp(const char *, const char *, size_t); }
 
 #define INT_MIN ((long)(-INT_MAX-1))
 
-#else /* not CFRONT_ANSI_BUG */
+#else /* !CFRONT_ANSI_BUG */
 
 #define INT_MIN (-INT_MAX-1)
 
-#endif /* not CFRONT_ANSI_BUG */
+#endif /* !CFRONT_ANSI_BUG */
 
 /* Maximum number of digits in the decimal representation of an int
-(not including the -). */
+   (not including the -). */
 
 #define INT_DIGITS 10
 
@@ -165,14 +151,14 @@ extern "C" { int strncasecmp(const char *, const char *, size_t); }
 const double PI = 3.14159265358979323846;
 
 /* ad_delete deletes an array of objects with destructors;
-a_delete deletes an array of objects without destructors */
+   a_delete deletes an array of objects without destructors */
 
 #ifdef ARRAY_DELETE_NEEDS_SIZE
 /* for 2.0 systems */
 #define ad_delete(size) delete [size]
 #define a_delete delete
-#else /* not ARRAY_DELETE_NEEDS_SIZE */
+#else /* !ARRAY_DELETE_NEEDS_SIZE */
 /* for ARM systems */
 #define ad_delete(size) delete []
 #define a_delete delete []
-#endif /* not ARRAY_DELETE_NEEDS_SIZE */
+#endif /* !ARRAY_DELETE_NEEDS_SIZE */
