@@ -1,6 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2003, 2004, 2006, 2009
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -16,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <assert.h>
 #include <string.h>
@@ -29,14 +28,14 @@ along with this program. If not, see <http://www.gnu.org/licenses/>. */
 # define name2x(a,b) a ## b
 #endif /* not TRADITIONAL_CPP */
 
-// `class PTABLE(T)' is the type of a hash table mapping a string
+// 'class PTABLE(T)' is the type of a hash table mapping a string
 // (const char *) to an object of type T.
 //
-// `struct PASSOC(T)' is the type of a association (pair) between a
+// 'struct PASSOC(T)' is the type of a association (pair) between a
 // string (const char *) and an object of type T.
 //
-// `class PTABLE_ITERATOR(T)' is the type of an iterator iterating through a
-// `class PTABLE(T)'.
+// 'class PTABLE_ITERATOR(T)' is the type of an iterator iterating through a
+// 'class PTABLE(T)'.
 //
 // Nowadays one would use templates for this; this code predates the addition
 // of templates to C++.
@@ -56,8 +55,8 @@ extern unsigned long hash_string(const char *);	// Return a hash code of the
 				// given string.  The hash function is
 				// platform dependent.  */
 
-// Declare the types `class PTABLE(T)', `struct PASSOC(T)', and `class
-// PTABLE_ITERATOR(T)' for the type `T'.
+// Declare the types 'class PTABLE(T)', 'struct PASSOC(T)', and 'class
+// PTABLE_ITERATOR(T)' for the type 'T'.
 #define declare_ptable(T)						      \
 									      \
 struct PASSOC(T) {							      \
@@ -86,8 +85,8 @@ class PTABLE(T) {							      \
   unsigned size;							      \
   unsigned used;							      \
   enum {								      \
-    FULL_NUM = 2,							      \
-    FULL_DEN = 3,							      \
+    FULL_NUM = 1,							      \
+    FULL_DEN = 4,							      \
     INITIAL_SIZE = 17							      \
   };									      \
 public:									      \
@@ -116,8 +115,8 @@ public:									      \
 // Values must be allocated by the caller (always using new[], not new)
 // and are freed by PTABLE.
 
-// Define the implementations of the members of the types `class PTABLE(T)',
-// `struct PASSOC(T)', `class PTABLE_ITERATOR(T)' for the type `T'.
+// Define the implementations of the members of the types 'class PTABLE(T)',
+// 'struct PASSOC(T)', 'class PTABLE_ITERATOR(T)' for the type 'T'.
 #define implement_ptable(T)						      \
 									      \
 PASSOC(T)::PASSOC(T)()							      \
@@ -134,8 +133,10 @@ PTABLE(T)::PTABLE(T)()							      \
 PTABLE(T)::~PTABLE(T)()							      \
 {									      \
   for (unsigned i = 0; i < size; i++) {					      \
-    a_delete v[i].key;							      \
-    a_delete v[i].val;							      \
+    free(v[i].key);							      \
+    /* XXX leak, because we don't know whether */			      \
+    /* 'free', 'delete', or 'delete[]' should be used */		      \
+    /* a_delete v[i].val; */						      \
   }									      \
   a_delete v;								      \
 }									      \
@@ -149,7 +150,9 @@ const char *PTABLE(T)::define(const char *key, T *val)			      \
        v[n].key != 0;							      \
        n = (n == 0 ? size - 1 : n - 1))					      \
     if (strcmp(v[n].key, key) == 0) {					      \
-      a_delete v[n].val;						      \
+      /* XXX leak, because we don't know whether */			      \
+      /* 'free', 'delete', or 'delete[]' should be used */		      \
+      /* a_delete v[n].val; */						      \
       v[n].val = val;							      \
       return v[n].key;							      \
     }									      \
@@ -163,7 +166,7 @@ const char *PTABLE(T)::define(const char *key, T *val)			      \
     for (unsigned i = 0; i < old_size; i++)				      \
       if (oldv[i].key != 0) {						      \
 	if (oldv[i].val == 0)						      \
-	  a_delete oldv[i].key;						      \
+	  free(oldv[i].key);						      \
 	else {								      \
 	  unsigned j;							      \
 	  for (j = unsigned(hash_string(oldv[i].key) % size);	      	      \
@@ -180,7 +183,7 @@ const char *PTABLE(T)::define(const char *key, T *val)			      \
       ;									      \
     a_delete oldv;							      \
   }									      \
-  char *temp = new char[strlen(key)+1];					      \
+  char *temp = (char*)malloc(strlen(key)+1);				      \
   strcpy(temp, key);							      \
   v[n].key = temp;							      \
   v[n].val = val;							      \
