@@ -1,5 +1,5 @@
 // -*- C++ -*- 
-/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -15,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "lib.h"
 
@@ -56,7 +56,7 @@ void search_list::add_file(const char *filename, int silent)
     int fd = open(filename, O_RDONLY | O_BINARY);
     if (fd < 0) {
       if (!silent)
-	error("can't open `%1': %2", filename, strerror(errno));
+        error("can't open '%1': %2", filename, strerror(errno));
     }
     else
       p = make_linear_search_item(fd, filename, next_fid);
