@@ -1,4 +1,4 @@
-/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -14,7 +14,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #define INT_DIGITS 19		/* enough for 64-bit integer */
 
@@ -22,10 +22,13 @@ along with this program. If not, see <http://www.gnu.org/licenses/>. */
 extern "C" {
 #endif
 
+/* Prototype */
+char *if_to_a(int, int);
+
 char *if_to_a(int i, int decimal_point)
 {
   /* room for a -, INT_DIGITS digits, a decimal point, and a terminating '\0' */
-  static char buf[INT_DIGITS + 3];			
+  static char buf[INT_DIGITS + 3];
   char *p = buf + INT_DIGITS + 2;
   int point = 0;
   buf[INT_DIGITS + 2] = '\0';
