@@ -1,5 +1,4 @@
-/* Copyright (C) 2004, 2009
-   Free Software Foundation, Inc.
+/* Copyright (C) 2004-2018 Free Software Foundation, Inc.
      Written by:  Jeff Conrad    (jeff_conrad@msn.com)
        and        Keith Marshall (keith.d.marshall@ntlworld.com)
 
@@ -16,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,7 +26,7 @@ along with this program. If not, see <http://www.gnu.org/licenses/>. */
 /* Define the default mechanism, and messages, for error reporting
  * (user may substitute a preferred alternative, by defining his own
  *  implementation of the macros REPORT_ERROR, QUOTE_ARG_MALLOC_FAILED
- *  and QUOTE_ARG_REALLOC_FAILED, in the header file `nonposix.h').
+ *  and QUOTE_ARG_REALLOC_FAILED, in the header file 'nonposix.h').
  */
 
 #include "nonposix.h"
@@ -44,6 +43,10 @@ along with this program. If not, see <http://www.gnu.org/licenses/>. */
 
 extern char *program_name;	/* main program must define this */
 
+/* Prototypes */
+char *quote_arg(char *);
+void purge_quoted_args(char **);
+
 #undef FALSE
 #undef TRUE
 #define FALSE 0
@@ -52,7 +55,7 @@ extern char *program_name;	/* main program must define this */
 static int
 needs_quoting(const char *string)
 {
-  /* Scan `string' to see whether it needs quoting for MSVC `spawn'/`exec'
+  /* Scan 'string' to see whether it needs quoting for MSVC 'spawn'/'exec'
    * (i.e., whether it contains whitespace or embedded quotes).
    */
 
@@ -76,7 +79,7 @@ needs_quoting(const char *string)
   }
 
   /* Fall through, if no quotes or white space found,
-   * in which case, return `FALSE'.
+   * in which case, return 'FALSE'.
    */
 
   return FALSE;
@@ -94,11 +97,11 @@ quote_arg(char *string)
   char *quoted, *p, *q;
 
   if (needs_quoting(string)) {
-    /* Need to create a quoted copy of `string';
+    /* Need to create a quoted copy of 'string';
      * maximum buffer space needed is twice the original length,
-     * plus two enclosing quotes and one `\0' terminator.
+     * plus two enclosing quotes and one '\0' terminator.
      */
-    
+
     if ((quoted = (char *)malloc(2 * strlen(string) + 3)) == NULL) {
       /* Couldn't get a buffer for the quoted string,
        * so complain, and bail out gracefully.
@@ -178,7 +181,7 @@ quote_arg(char *string)
     }
   }
 
-  /* `string' now refers to the argument,
+  /* 'string' now refers to the argument,
    * quoted and escaped, as required.
    */
 
@@ -189,16 +192,16 @@ void
 purge_quoted_args(char **argv)
 {
   /* To avoid memory leaks,
-   * free all memory previously allocated by `quoted_arg()',
-   * within the scope of the referring argument vector, `argv'.
+   * free all memory previously allocated by 'quoted_arg()',
+   * within the scope of the referring argument vector, 'argv'.
    */
 
   if (argv)
     while (*argv) {
       /* Any argument beginning with a double quote
-       * SHOULD have been allocated by `quoted_arg()'.
+       * SHOULD have been allocated by 'quoted_arg()'.
        */
-      
+
       if (**argv == '"')
         free( *argv );		/* so free its allocation */
       ++argv;			/* and continue to the next argument */
