@@ -1,6 +1,6 @@
 // -*- C++ -*-
 /* Provide relocation for macro and font files.
-   Copyright (C) 2005, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2005-2018 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published
@@ -13,7 +13,7 @@
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public License
-   along with this program. If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 // Made after relocation code in kpathsea and gettext.
 
@@ -43,7 +43,7 @@ extern "C" const char *program_name;
 char *curr_prefix = 0;
 size_t curr_prefix_len = 0;
 
-// Return the directory part of a filename, or `.' if no path separators.
+// Return the directory part of a filename, or '.' if no path separators.
 char *xdirname(char *s)
 {
   static const char dot[] = ".";
@@ -75,8 +75,8 @@ char *searchpath(const char *name, const char *pathp)
   if (!name || !*name)
     return 0;
 #if DEBUG
-  fprintf(stderr, "searchpath: pathp: `%s'\n", pathp);
-  fprintf(stderr, "searchpath: trying `%s'\n", name);
+  fprintf(stderr, "searchpath: pathp: '%s'\n", pathp);
+  fprintf(stderr, "searchpath: trying '%s'\n", name);
 #endif
   // Try first NAME as such; success if NAME is an absolute filename,
   // or if NAME is found in the current directory.
@@ -88,7 +88,7 @@ char *searchpath(const char *name, const char *pathp)
     path = realpath(name, path);
 #endif
 #if DEBUG
-    fprintf(stderr, "searchpath: found `%s'\n", path);
+    fprintf(stderr, "searchpath: found '%s'\n", path);
 #endif
     return path;
   }
@@ -107,11 +107,11 @@ char *searchpath(const char *name, const char *pathp)
       path[end - p] = '/';
     strcpy(path + (end - p) + need_slash, name);
 #if DEBUG
-    fprintf(stderr, "searchpath: trying `%s'\n", path);
+    fprintf(stderr, "searchpath: trying '%s'\n", path);
 #endif
     if (!access(path, F_OK)) {
 #if DEBUG
-      fprintf(stderr, "searchpath: found `%s'\n", name);
+      fprintf(stderr, "searchpath: found '%s'\n", name);
 #endif
       return path;
     }
