@@ -1,6 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 2002, 2003, 2004, 2006, 2009
-   Free Software Foundation, Inc.
+/* Copyright (C) 2002-2018 Free Software Foundation, Inc.
      Written by Werner Lemberg <wl@gnu.org>
 
 This file is part of groff.
@@ -16,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "lib.h"
 #include "stringclass.h"
@@ -230,7 +229,7 @@ struct S {
   { "00AC", "no" },
 //{ "00AC", "tno" },
   // In groff, U+00AD is an input character only; it is not mapped to
-  // a glyph but to `\%'.
+  // a glyph but to '\%'.
   { "00AE", "rg" },
   { "00AF", "a-" },
   { "00B0", "de" },
@@ -271,6 +270,7 @@ struct S {
   { "0152", "OE" },
   { "0153", "oe" },
   { "0192", "Fn" },
+  { "0237", ".j" },
   { "02C7", "ah" },
   { "02D8", "ab" },
   { "02D9", "a." },
@@ -322,12 +322,12 @@ struct S {
   { "03C3", "*s" },
   { "03C4", "*t" },
   { "03C5", "*u" },
-  { "03C6", "*f" },
+  { "03C6", "+f" },
   { "03C7", "*x" },
   { "03C8", "*q" },
   { "03C9", "*w" },
   { "03D1", "+h" },
-  { "03D5", "+f" },
+  { "03D5", "*f" },
   { "03D6", "+p" },
   { "03F5", "+e" },
 //{ "2010", "-" },
@@ -460,12 +460,6 @@ struct S {
 //{ "23AD", "bracerightbt" },
   { "23AF", "an" },
   { "2502", "br" },
-  { "251D", "rk" },
-  { "2525", "lk" },
-  { "256D", "lt" },
-  { "256E", "rt" },
-  { "256F", "rb" },
-  { "2570", "lb" },
   { "25A1", "sq" },
   { "25CA", "lz" },
   { "25CB", "ci" },
