@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -15,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "eqn.h"
 #include "pbox.h"
@@ -131,7 +131,7 @@ void set_param(const char *name, int value)
       *param_table[i].ptr = value;
       return;
     }
-  error("unrecognised parameter `%1'", name);
+  error("unrecognised parameter '%1'", name);
 }
 
 int script_style(int style)
@@ -360,7 +360,7 @@ void box::top_level()
   next_uid = 0;
 }
 
-// gpic defines this register so as to make geqn not produce `\x's
+// gpic defines this register so as to make geqn not produce '\x's
 #define EQN_NO_EXTRA_SPACE_REG "0x"
 
 void box::extra_space()
@@ -551,7 +551,7 @@ quoted_text_box::quoted_text_box(char *s) : text(s)
 
 quoted_text_box::~quoted_text_box()
 {
-  a_delete text;
+  free(text);
 }
 
 void quoted_text_box::output()
