@@ -1,22 +1,21 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2002 Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
 
 groff is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 groff is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
-You should have received a copy of the GNU General Public License along
-with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "eqn.h"
 #include "pbox.h"
@@ -139,33 +138,56 @@ int limit_box::compute_metrics(int style)
 
 void limit_box::output()
 {
-  printf("\\s[\\n[" SMALL_SIZE_FORMAT "]u]", uid);
-  if (to != 0) {
+  if (output_format == troff) {
+    printf("\\s[\\n[" SMALL_SIZE_FORMAT "]u]", uid);
+    if (to != 0) {
+      printf("\\Z" DELIMITER_CHAR);
+      printf("\\v'-\\n[" SUP_RAISE_FORMAT "]u'", uid);
+      printf("\\h'\\n[" LEFT_WIDTH_FORMAT "]u"
+	     "+(-\\n[" WIDTH_FORMAT "]u+\\n[" SUB_KERN_FORMAT "]u/2u)'",
+	     uid, to->uid, p->uid);
+      to->output();
+      printf(DELIMITER_CHAR);
+    }
+    if (from != 0) {
+      printf("\\Z" DELIMITER_CHAR);
+      printf("\\v'\\n[" SUB_LOWER_FORMAT "]u'", uid);
+      printf("\\h'\\n[" LEFT_WIDTH_FORMAT "]u"
+	     "+(-\\n[" SUB_KERN_FORMAT "]u-\\n[" WIDTH_FORMAT "]u/2u)'",
+	     uid, p->uid, from->uid);
+      from->output();
+      printf(DELIMITER_CHAR);
+    }
+    printf("\\s[\\n[" SIZE_FORMAT "]u]", uid);
     printf("\\Z" DELIMITER_CHAR);
-    printf("\\v'-\\n[" SUP_RAISE_FORMAT "]u'", uid);
     printf("\\h'\\n[" LEFT_WIDTH_FORMAT "]u"
-	   "+(-\\n[" WIDTH_FORMAT "]u+\\n[" SUB_KERN_FORMAT "]u/2u)'",
-	   uid, to->uid, p->uid);
-    to->output();
+	   "-(\\n[" WIDTH_FORMAT "]u/2u)'",
+	   uid, p->uid);
+    p->output();
     printf(DELIMITER_CHAR);
+    printf("\\h'\\n[" WIDTH_FORMAT "]u'", uid);
   }
-  if (from != 0) {
-    printf("\\Z" DELIMITER_CHAR);
-    printf("\\v'\\n[" SUB_LOWER_FORMAT "]u'", uid);
-    printf("\\h'\\n[" LEFT_WIDTH_FORMAT "]u"
-	   "+(-\\n[" SUB_KERN_FORMAT "]u-\\n[" WIDTH_FORMAT "]u/2u)'",
-	   uid, p->uid, from->uid);
-    from->output();
-    printf(DELIMITER_CHAR);
+  else if (output_format == mathml) {
+    if (from != 0 && to != 0) {
+      printf("<munderover>");
+      p->output();
+      from->output();
+      to->output();
+      printf("</munderover>");
+    }
+    else if (from != 0) {
+      printf("<munder>");
+      p->output();
+      from->output();
+      printf("</munder>");
+    }
+    else if (to != 0) {
+      printf("<mover>");
+      p->output();
+      to->output();
+      printf("</mover>");
+    }
   }
-  printf("\\s[\\n[" SIZE_FORMAT "]u]", uid);
-  printf("\\Z" DELIMITER_CHAR);
-  printf("\\h'\\n[" LEFT_WIDTH_FORMAT "]u"
-	 "-(\\n[" WIDTH_FORMAT "]u/2u)'",
-	 uid, p->uid);
-  p->output();
-  printf(DELIMITER_CHAR);
-  printf("\\h'\\n[" WIDTH_FORMAT "]u'", uid);
 }
 
 void limit_box::debug_print()
