@@ -6,6 +6,10 @@
  * gremlin picture editor.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include "gprint.h"
 #include <string.h>
@@ -94,7 +98,7 @@ DBRead(register FILE *file)
   (void) fscanf(file, "%" MAXSTRING_S "s%*[^\n]\n", string);
   if (strcmp(string, "gremlinfile")) {
     if (strcmp(string, "sungremlinfile")) {
-      error("`%1' is not a gremlin file", gremlinfile);
+      error("'%1' is not a gremlin file", gremlinfile);
       return (elist);
     }
     SUNFILE = TRUE;
@@ -109,7 +113,7 @@ DBRead(register FILE *file)
     /* I changed the scanf format because the element */
     /* can have two words (e.g. CURVE SPLINE)         */
     if (fscanf(file, "\n%" MAXSTRING_S "[^\n]%*[^\n]\n", string) == EOF) {
-      error("`%1', error in file format", gremlinfile);
+      error("'%1', error in file format", gremlinfile);
       return (elist);
     }
 
@@ -241,6 +245,7 @@ DBGetType(register char *s)
       return (CENTRIGHT);
     default:
       fatal("unknown element type");
+      // fatal() does not return
     }
   case 'B':
     switch (s[3]) {
@@ -252,6 +257,7 @@ DBGetType(register char *s)
       return (BOTRIGHT);
     default:
       fatal("unknown element type");
+      // fatal() does not return
     }
   case 'T':
     switch (s[3]) {
@@ -263,6 +269,7 @@ DBGetType(register char *s)
       return (TOPRIGHT);
     default:
       fatal("unknown element type");
+      // fatal() does not return
     }
   default:
     fatal("unknown element type");
