@@ -1,22 +1,21 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992 Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
 
 groff is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
-version.
+Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 groff is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
 FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
-You should have received a copy of the GNU General Public License along
-with groff; see the file COPYING.  If not, write to the Free Software
-Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 class common_output : public output {
 private:
@@ -33,8 +32,13 @@ private:
 	       double gap_width, double *offsetp);
 protected:
   virtual void dot(const position &, const line_type &) = 0;
+  void ellipse_arc(const position &, const position &,
+		   const position &, const distance &,
+		   const line_type &);
   void dashed_circle(const position &, double rad, const line_type &);
   void dotted_circle(const position &, double rad, const line_type &);
+  void dashed_ellipse(const position &, const distance &, const line_type &);
+  void dotted_ellipse(const position &, const distance &, const line_type &);
   void dashed_arc(const position &, const position &, const position &,
 		  const line_type &);
   void dotted_arc(const position &, const position &, const position &,
@@ -47,7 +51,8 @@ protected:
 			  const line_type &);
   void solid_rounded_box(const position &, const distance &, double,
 			 const line_type &);
-  void filled_rounded_box(const position &, const distance &, double, double);
+  void filled_rounded_box(const position &, const distance &, double,
+			  double);
 public:
   void start_picture(double sc, const position &ll, const position &ur) = 0;
   void finish_picture() = 0;
@@ -62,7 +67,7 @@ public:
   void ellipse(const position &, const distance &,
 	       const line_type &, double) = 0;
   void rounded_box(const position &, const distance &, double,
-		   const line_type &, double);
+		   const line_type &, double, char *);
   void set_color(char *, char *) = 0;
   void reset_color() = 0;
   char *get_last_filled() = 0;
