@@ -1,6 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2001, 2003, 2008, 2009
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
 Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -16,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
      
 #include "refer.h"
 #include "refid.h"
@@ -366,7 +365,7 @@ void sortify_date(const char *s, int len, string &key)
   const char *year_end;
   const char *year_start = find_year(s, s + len, &year_end);
   if (!year_start) {
-    // Things without years are often `forthcoming', so it makes sense
+    // Things without years are often 'forthcoming', so it makes sense
     // that they sort after things with explicit years.
     key += 'A';
     sortify_words(s, s + len, 0, key);
