@@ -1,6 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002, 2004, 2009
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -16,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 
 // diversions
@@ -179,12 +178,12 @@ macro_diversion::macro_diversion(symbol s, int append)
 {
 #if 0
   if (append) {
-    /* We don't allow recursive appends eg:
+    /* We don't allow recursive appends, e.g.:
 
       .da a
       .a
       .di
-      
+
       This causes an infinite loop in troff anyway.
       This is because the user could do
 
@@ -203,9 +202,9 @@ macro_diversion::macro_diversion(symbol s, int append)
       .a
       .di
 
-       will work and will make `a' contain two copies of what it contained
-       before; in troff, `a' would contain nothing. */
-    request_or_macro *rm 
+       will work and will make 'a' contain two copies of what it contained
+       before; in troff, 'a' would contain nothing. */
+    request_or_macro *rm
       = (request_or_macro *)request_dictionary.remove(s);
     if (!rm || (mac = rm->to_macro()) == 0)
       mac = new macro;
@@ -218,7 +217,7 @@ macro_diversion::macro_diversion(symbol s, int append)
   // stored in the macro. When we detect this, we copy the contents.
   mac = new macro(1);
   if (append) {
-    request_or_macro *rm 
+    request_or_macro *rm
       = (request_or_macro *)request_dictionary.lookup(s);
     if (rm) {
       macro *m = rm->to_macro();
@@ -548,7 +547,7 @@ void top_level_diversion::print_traps()
 void end_diversions()
 {
   while (curdiv != topdiv) {
-    error("automatically ending diversion `%1' on exit",
+    error("automatically ending diversion '%1' on exit",
 	    curdiv->nm.contents());
     diversion *tem = curdiv;
     curdiv = curdiv->prev;
