@@ -1,6 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989-1992, 2000-2006, 2009, 2011
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -16,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "troff.h"
 #include "dictionary.h"
@@ -39,7 +38,17 @@ symbol default_family("T");
 
 enum { ADJUST_LEFT = 0, ADJUST_BOTH = 1, ADJUST_CENTER = 3, ADJUST_RIGHT = 5 };
 
-enum { HYPHEN_LAST_LINE = 2, HYPHEN_LAST_CHARS = 4, HYPHEN_FIRST_CHARS = 8 };
+enum {
+  // Not all combinations are valid; see hyphenate_request() below.
+  HYPHEN_NONE = 0,
+  HYPHEN_DEFAULT = 1,
+  HYPHEN_NOT_LAST_LINE = 2,
+  HYPHEN_NOT_LAST_CHARS = 4,
+  HYPHEN_NOT_FIRST_CHARS = 8,
+  HYPHEN_LAST_CHAR = 16,
+  HYPHEN_FIRST_CHAR = 32,
+  HYPHEN_MAX = 63,
+};
 
 struct env_list {
   environment *env;
@@ -696,7 +705,7 @@ environment::environment(symbol nm)
   if (!is_good_fontno(1))
     fatal("font number 1 not a valid font");
   if (family->make_definite(1) < 0)
-    fatal("invalid default family `%1'", default_family.contents());
+    fatal("invalid default family '%1'", default_family.contents());
   prev_fontno = fontno;
 }
 
@@ -778,7 +787,7 @@ environment::environment(const environment *e)
   suppress_next_eol(e->suppress_next_eol),
   seen_break(e->seen_break),
   tabs(e->tabs),
-  name(e->name),		// so that eg `.if "\n[.ev]"0"' works
+  name(e->name),		// so that, e.g., '.if "\n[.ev]"0"' works
   control_char(e->control_char),
   no_break_control_char(e->no_break_control_char),
   hyphen_indicator_char(e->hyphen_indicator_char)
@@ -1260,7 +1269,7 @@ void override_sizes()
 	break;
       // fall through
     default:
-      warning(WARN_RANGE, "bad size range `%1'", p);
+      warning(WARN_RANGE, "bad size range '%1'", p);
       return;
     }
     if (i + 2 > n) {
@@ -1652,8 +1661,20 @@ void no_hyphenate()
 void hyphenate_request()
 {
   int n;
-  if (has_arg() && get_integer(&n))
-    curenv->hyphenation_flags = n;
+  if (has_arg() && get_integer(&n)) {
+    if (n < HYPHEN_NONE) {
+      warning(WARN_RANGE, "negative hyphenation flags ignored: %1", n);
+    } else if (n > HYPHEN_MAX) {
+      warning(WARN_RANGE, "unknown hyphenation flags ignored (maximum "
+	"%1): %2", HYPHEN_MAX, n);
+    } else if (((n & HYPHEN_DEFAULT) && (n & ~HYPHEN_DEFAULT))
+	|| ((n & HYPHEN_FIRST_CHAR) && (n & HYPHEN_NOT_FIRST_CHARS))
+	|| ((n & HYPHEN_LAST_CHAR) && (n & HYPHEN_NOT_LAST_CHARS)))
+      warning(WARN_SYNTAX, "contradictory hyphenation flags ignored: "
+	"%1", n);
+    else
+      curenv->hyphenation_flags = n;
+  }
   else
     curenv->hyphenation_flags = 1;
   skip_line();
@@ -1691,8 +1712,8 @@ void environment::newline()
       prev_fontno = fontno;
       fontno = pre_underline_fontno;
       if (underline_spaces) {
-        underline_spaces = 0;
-        add_node(do_underline_special(0));
+	underline_spaces = 0;
+	add_node(do_underline_special(0));
       }
     }
   }
@@ -2021,10 +2042,14 @@ void environment::hyphenate_line(int start_here)
   if (hyphenation_flags != 0
       && !inhibit
       // this may not be right if we have extra space on this line
-      && !((hyphenation_flags & HYPHEN_LAST_LINE)
+      && !((hyphenation_flags & HYPHEN_NOT_LAST_LINE)
 	   && (curdiv->distance_to_next_trap()
 	       <= vertical_spacing + total_post_vertical_spacing()))
-      && i >= 4)
+      && i >= (4
+	       - (hyphenation_flags & HYPHEN_FIRST_CHAR ? 1 : 0)
+	       - (hyphenation_flags & HYPHEN_LAST_CHAR ? 1 : 0)
+	       + (hyphenation_flags & HYPHEN_NOT_FIRST_CHARS ? 1 : 0)
+	       + (hyphenation_flags & HYPHEN_NOT_LAST_CHARS ? 1 : 0)))
     hyphenate(sl, hyphenation_flags);
   while (forward != 0) {
     node *tem1 = forward;
@@ -2228,15 +2253,15 @@ node *environment::make_tag(const char *nm, int i)
 void environment::dump_troff_state()
 {
 #define SPACES "                                            "
-  fprintf(stderr, SPACES "register `in' = %d\n", curenv->indent.to_units());
+  fprintf(stderr, SPACES "register 'in' = %d\n", curenv->indent.to_units());
   if (curenv->have_temporary_indent)
-    fprintf(stderr, SPACES "register `ti' = %d\n",
+    fprintf(stderr, SPACES "register 'ti' = %d\n",
 	    curenv->temporary_indent.to_units());
-  fprintf(stderr, SPACES "centered lines `ce' = %d\n", curenv->center_lines);
-  fprintf(stderr, SPACES "register `ll' = %d\n",
+  fprintf(stderr, SPACES "centered lines 'ce' = %d\n", curenv->center_lines);
+  fprintf(stderr, SPACES "register 'll' = %d\n",
 	  curenv->line_length.to_units());
-  fprintf(stderr, SPACES "fill `fi=1/nf=0' = %d\n", curenv->fill);
-  fprintf(stderr, SPACES "page offset `po' = %d\n",
+  fprintf(stderr, SPACES "fill 'fi=1/nf=0' = %d\n", curenv->fill);
+  fprintf(stderr, SPACES "page offset 'po' = %d\n",
 	  topdiv->get_page_offset().to_units());
   fprintf(stderr, SPACES "seen_break = %d\n", curenv->seen_break);
   fprintf(stderr, SPACES "seen_space = %d\n", curenv->seen_space);
@@ -2486,7 +2511,7 @@ void adjust()
 	  warning(WARN_RANGE, "negative adjustment mode");
 	else if (n > 5) {
 	  curenv->adjust_mode = 5;
-	  warning(WARN_RANGE, "adjustment mode `%1' out of range", n);
+	  warning(WARN_RANGE, "adjustment mode '%1' out of range", n);
 	}
 	else
 	  curenv->adjust_mode = n;
@@ -2507,6 +2532,8 @@ void do_input_trap(int continued)
   curenv->input_trap_count = 0;
   if (continued)
     curenv->continued_input_trap = 1;
+  else
+    curenv->continued_input_trap = 0;
   int n;
   if (has_arg() && get_integer(&n)) {
     if (n <= 0)
@@ -2544,40 +2571,8 @@ struct tab {
   tab_type type;
   tab(hunits, tab_type);
   enum { BLOCK = 1024 };
-  static tab *free_list;
-  void *operator new(size_t);
-  void operator delete(void *);
 };
 
-tab *tab::free_list = 0;
-
-void *tab::operator new(size_t n)
-{
-  assert(n == sizeof(tab));
-  if (!free_list) {
-    free_list = (tab *)new char[sizeof(tab)*BLOCK];
-    for (int i = 0; i < BLOCK - 1; i++)
-      free_list[i].next = free_list + i + 1;
-    free_list[BLOCK-1].next = 0;
-  }
-  tab *p = free_list;
-  free_list = (tab *)(free_list->next);
-  p->next = 0;
-  return p;
-}
-
-#ifdef __GNUG__
-/* cfront can't cope with this. */
-inline
-#endif
-void tab::operator delete(void *p)
-{
-  if (p) {
-    ((tab *)p)->next = free_list;
-    free_list = (tab *)p;
-  }
-}
-
 tab::tab(hunits x, tab_type t) : next(0), pos(x), type(t)
 {
 }
@@ -3254,8 +3249,8 @@ void environment::print_env()
   errprint("  requested size: %1s\n", requested_size);
   errprint("  previous font number: %1\n", prev_fontno);
   errprint("  font number: %1\n", fontno);
-  errprint("  previous family: `%1'\n", prev_family->nm.contents());
-  errprint("  family: `%1'\n", family->nm.contents());
+  errprint("  previous family: '%1'\n", prev_family->nm.contents());
+  errprint("  family: '%1'\n", family->nm.contents());
   errprint("  space size: %1/36 em\n", space_size);
   errprint("  sentence space size: %1/36 em\n", sentence_space_size);
   errprint("  previous line interrupted: %1\n",
@@ -3295,7 +3290,7 @@ void environment::print_env()
     errprint("  underline spaces: %1\n", underline_spaces ? "yes" : "no");
   }
   if (input_trap.contents()) {
-    errprint("  input trap macro: `%1'\n", input_trap.contents());
+    errprint("  input trap macro: '%1'\n", input_trap.contents());
     errprint("  input trap line counter: %1\n", input_trap_count);
     errprint("  continued input trap: %1\n",
 	     continued_input_trap ? "yes" : "no");
@@ -3333,11 +3328,15 @@ void environment::print_env()
     errprint("  lines not to enumerate: %1\n", no_number_count);
   }
   string hf = hyphenation_flags ? "on" : "off";
-  if (hyphenation_flags & HYPHEN_LAST_LINE)
+  if (hyphenation_flags & HYPHEN_NOT_LAST_LINE)
     hf += ", not last line";
-  if (hyphenation_flags & HYPHEN_LAST_CHARS)
+  if (hyphenation_flags & HYPHEN_LAST_CHAR)
+    hf += ", last char";
+  if (hyphenation_flags & HYPHEN_NOT_LAST_CHARS)
     hf += ", not last two chars";
-  if (hyphenation_flags & HYPHEN_FIRST_CHARS)
+  if (hyphenation_flags & HYPHEN_FIRST_CHAR)
+    hf += ", first char";
+  if (hyphenation_flags & HYPHEN_NOT_FIRST_CHARS)
     hf += ", not first two chars";
   hf += '\0';
   errprint("  hyphenation_flags: %1\n", hf.contents());
@@ -3697,7 +3696,7 @@ void hyphen_trie::insert_pattern(const char *pat, int patlen, int *num)
 void hyphen_trie::insert_hyphenation(dictionary *ex, const char *pat,
 				     int patlen)
 {
-  char buf[WORD_MAX + 1];
+  char buf[WORD_MAX + 2];
   unsigned char pos[WORD_MAX + 2];
   int i = 0, j = 0;
   int npos = 0;
@@ -3707,6 +3706,8 @@ void hyphen_trie::insert_hyphenation(dictionary *ex, const char *pat,
       if (i > 0 && (npos == 0 || pos[npos - 1] != i))
 	pos[npos++] = i;
     }
+    else if (c == ' ')
+      buf[i++] = ' ';
     else
       buf[i++] = hpf_code_table[c];
   }
@@ -3758,28 +3759,28 @@ void hyphen_trie::do_delete(void *v)
 
 /* We use very simple rules to parse TeX's hyphenation patterns.
 
-   . `%' starts a comment even if preceded by `\'.
+   . '%' starts a comment even if preceded by '\'.
 
-   . No support for digraphs and like `\$'.
+   . No support for digraphs and like '\$'.
 
-   . `^^xx' (`x' is 0-9 or a-f), and `^^x' (character code of `x' in the
-     range 0-127) are recognized; other use of `^' causes an error.
+   . '^^xx' ('x' is 0-9 or a-f), and '^^x' (character code of 'x' in the
+     range 0-127) are recognized; other use of '^' causes an error.
 
    . No macro expansion.
 
-   . We check for the expression `\patterns{...}' (possibly with
+   . We check for the expression '\patterns{...}' (possibly with
      whitespace before and after the braces).  Everything between the
-     braces is taken as hyphenation patterns.  Consequently, `{' and `}'
+     braces is taken as hyphenation patterns.  Consequently, '{' and '}'
      are not allowed in patterns.
 
-   . Similarly, `\hyphenation{...}' gives a list of hyphenation
+   . Similarly, '\hyphenation{...}' gives a list of hyphenation
      exceptions.
 
-   . `\endinput' is recognized also.
+   . '\endinput' is recognized also.
 
-   . For backwards compatibility, if `\patterns' is missing, the
+   . For backwards compatibility, if '\patterns' is missing, the
      whole file is treated as a list of hyphenation patterns (only
-     recognizing `%' as the start of a comment.
+     recognizing '%' as the start of a comment.
 
 */
 
@@ -3827,15 +3828,15 @@ void hyphen_trie::read_patterns_file(const char *name, int append,
 {
   if (!append)
     clear();
-  char buf[WORD_MAX];
-  for (int i = 0; i < WORD_MAX; i++)
+  char buf[WORD_MAX + 1];
+  for (int i = 0; i < WORD_MAX + 1; i++)
     buf[i] = 0;
-  int num[WORD_MAX+1];
+  int num[WORD_MAX + 1];
   errno = 0;
   char *path = 0;
   FILE *fp = mac_path->open_file(name, &path);
   if (fp == 0) {
-    error("can't find hyphenation patterns file `%1'", name);
+    error("can't find hyphenation patterns file '%1'", name);
     return;
   }
   int c = hpf_getc(fp);
@@ -3859,7 +3860,7 @@ void hyphen_trie::read_patterns_file(const char *name, int append,
     if (c == EOF) {
       if (have_keyword || traditional)	// we are done
 	break;
-      else {				// rescan file in `traditional' mode
+      else {				// rescan file in 'traditional' mode
 	rewind(fp);
 	traditional = 1;
 	c = hpf_getc(fp);
@@ -3932,7 +3933,7 @@ void hyphen_trie::read_patterns_file(const char *name, int append,
       }
       else if (c == '{') {
 	if (have_patterns || have_hyphenation)
-	  error("`{' not allowed within %1 group",
+	  error("'{' not allowed within %1 group",
 		have_patterns ? "\\patterns" : "\\hyphenation");
 	c = hpf_getc(fp);		// skipped if not starting \patterns
 					// or \hyphenation
@@ -3950,13 +3951,16 @@ void hyphen_trie::read_patterns_file(const char *name, int append,
 	final_pattern = 0;
       }
       else if (have_hyphenation || final_hyphenation) {
+	// hyphenation exceptions in a pattern file are subject to `.hy'
+	// restrictions; we mark such entries with a trailing space
+	buf[i++] = ' ';
 	insert_hyphenation(ex, buf, i);
 	final_hyphenation = 0;
       }
     }
   }
   fclose(fp);
-  a_delete path;
+  free(path);
   return;
 }
 
@@ -3978,7 +3982,8 @@ void hyphenate(hyphen_list *h, unsigned flags)
 	break;
     }
     hyphen_list *nexth = tem;
-    if (len > 2) {
+    if (len >= 2) {
+      // check `.hw' entries
       buf[len] = 0;
       unsigned char *pos
 	= (unsigned char *)current_language->exceptions.lookup(buf);
@@ -3992,18 +3997,61 @@ void hyphenate(hyphen_list *h, unsigned flags)
 	  }
       }
       else {
-	hbuf[0] = hbuf[len + 1] = '.';
-	int num[WORD_MAX + 3];
-	current_language->patterns.hyphenate(hbuf, len + 2, num);
-	int i;
-	num[2] = 0;
-	if (flags & HYPHEN_FIRST_CHARS)
-	  num[3] = 0;
-	if (flags & HYPHEN_LAST_CHARS)
-	  --len;
-	for (i = 2, tem = h; i < len && tem; tem = tem->next, i++)
-	  if (num[i] & 1)
-	    tem->hyphen = 1;
+	// check `\hyphenation' entries from pattern files;
+	// such entries are marked with a trailing space
+	buf[len] = ' ';
+	buf[len + 1] = 0;
+	pos = (unsigned char *)current_language->exceptions.lookup(buf);
+	if (pos != 0) {
+	  int j = 0;
+	  int i = 1;
+	  tem = h;
+	  if (pos[j] == i) {
+	    if (flags & HYPHEN_FIRST_CHAR)
+	      tem->hyphen = 1;
+	    j++;
+	  }
+	  tem = tem->next;
+	  i++;
+	  if (pos[j] == i) {
+	    if (!(flags & HYPHEN_NOT_FIRST_CHARS))
+	      tem->hyphen = 1;
+	    j++;
+	  }
+	  tem = tem->next;
+	  i++;
+	  if (!(flags & HYPHEN_LAST_CHAR))
+	    --len;
+	  if (flags & HYPHEN_NOT_LAST_CHARS)
+	    --len;
+	  for (; i < len && tem; tem = tem->next, i++)
+	    if (pos[j] == i) {
+	      tem->hyphen = 1;
+	      j++;
+	    }
+	}
+	else {
+	  hbuf[0] = hbuf[len + 1] = '.';
+	  int num[WORD_MAX + 3];
+	  current_language->patterns.hyphenate(hbuf, len + 2, num);
+	  // The position of a hyphenation point gets marked with an odd
+	  // number.  Example:
+	  //
+	  //   hbuf:  . h e l p f u l .
+	  //   num:  0 0 0 2 4 3 0 0 0 0
+	  if (!(flags & HYPHEN_FIRST_CHAR))
+	    num[2] = 0;
+	  if (flags & HYPHEN_NOT_FIRST_CHARS)
+	    num[3] = 0;
+	  if (flags & HYPHEN_LAST_CHAR)
+	    ++len;
+	  if (flags & HYPHEN_NOT_LAST_CHARS)
+	    --len;
+	  int i;
+	  for (i = 2, tem = h; i < len && tem; tem = tem->next, i++)
+	    if (num[i] & 1)
+	      tem->hyphen = 1;
+	}
       }
     }
     h = nexth;
