@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989-2014  Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -15,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 
 class charinfo;
@@ -41,18 +41,18 @@ class token {
     TOKEN_ITALIC_CORRECTION,	// \/
     TOKEN_LEADER,		// ^A
     TOKEN_LEFT_BRACE,
-    TOKEN_MARK_INPUT,		// \k -- `nm' is the name of the register
+    TOKEN_MARK_INPUT,		// \k -- 'nm' is the name of the register
     TOKEN_NEWLINE,		// newline
     TOKEN_NODE,
     TOKEN_NUMBERED_CHAR,
     TOKEN_PAGE_EJECTOR,
     TOKEN_REQUEST,
     TOKEN_RIGHT_BRACE,
-    TOKEN_SPACE,		// ` ' -- ordinary space
+    TOKEN_SPACE,		// ' ' -- ordinary space
     TOKEN_SPECIAL,		// a special character -- \' \` \- \(xx \[xxx]
-    TOKEN_SPREAD,		// \p -- break and spread output line 
+    TOKEN_SPREAD,		// \p -- break and spread output line
     TOKEN_STRETCHABLE_SPACE,	// \~
-    TOKEN_UNSTRETCHABLE_SPACE,	// `\ '
+    TOKEN_UNSTRETCHABLE_SPACE,	// '\ '
     TOKEN_HORIZONTAL_SPACE,	// \|, \^, \0, \h
     TOKEN_TAB,			// tab
     TOKEN_TRANSPARENT,		// \!
