@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1994-2014  Free Software Foundation, Inc.
+/* Copyright (C) 1994-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -15,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 /*
 TODO
@@ -344,7 +344,7 @@ main(int argc, char **argv)
   current_lineno = -1;		// no line numbers
   if (!debug_flag && !equal(argv[optind + 2], "-"))
     if (freopen(argv[optind + 2], "w", stdout) == NULL)
-      fatal("cannot open `%1': %2", argv[optind + 2], strerror(errno));
+      fatal("cannot open '%1': %2", argv[optind + 2], strerror(errno));
   current_filename = argv[optind];
 
   check_units(f, tfm_type, &ppi, &upem);
@@ -403,7 +403,7 @@ File::File(const char *s)
   // on byte counts.
   int fd = open(s, O_RDONLY | O_BINARY);
   if (fd < 0)
-    fatal("cannot open `%1': %2", s, strerror(errno));
+    fatal("cannot open '%1': %2", s, strerror(errno));
   current_filename = s;
   struct stat sb;
   if (fstat(fd, &sb) < 0)
@@ -938,7 +938,7 @@ output_charset(const int tfm_type)
 	     && charcode_name_table[charcode]) {
       char *name = charcode_name_table[charcode]->name;
       // don't warn about Unicode or unnamed glyphs
-      //  that aren't in the the TFM file
+      //  that aren't in the TFM file
       if (tfm_type == UNICODE && !quiet_flag && !equal(name, UNNAMED)
 	  && !is_uname(name)) {
 	fprintf(stderr, "%s: warning: symbol U+%04X (%s",
@@ -1339,7 +1339,7 @@ read_map(const char *file, const int tfm_type)
   errno = 0;
   FILE *fp = fopen(file, "r");
   if (!fp) {
-    error("can't open `%1': %2", file, strerror(errno));
+    error("can't open '%1': %2", file, strerror(errno));
     return 0;
   }
   current_filename = file;
