@@ -1,6 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989-1992, 2000, 2001, 2002, 2003, 2009
-   Free Software Foundation, Inc.
+/* Copyright (C) 1989-2018 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -16,7 +15,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program. If not, see <http://www.gnu.org/licenses/>. */
+along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "lib.h"
 
@@ -35,9 +34,7 @@ along with this program. If not, see <http://www.gnu.org/licenses/>. */
 #include "posix.h"
 #include "nonposix.h"
 
-extern "C" {
-  const char *Version_string;
-}
+extern "C" const char *Version_string;
 
 static void usage(FILE *stream)
 {
@@ -69,7 +66,7 @@ int main(int argc, char **argv)
 	char *ptr;
 	long n = strtol(optarg, &ptr, 10);
 	if (n == 0 && ptr == optarg) {
-	  error("bad integer `%1' in `t' option", optarg);
+	  error("bad integer '%1' in 't' option", optarg);
 	  break;
 	}
 	if (n < 1)
